Create a job queue and return a job queue object

create_job_queue(qfile, mapsize = 2^30, ...)

Arguments

qfile

the name of the queue

mapsize

size of the map for LMDB database

...

other arguments to be passed to mdb_env

Value

an object of class "job_queue" (invisibly) fet

Details

The queue will be created as a subdirectory named qfile under the current working directory