Return the next queue element and remove it from the queue

dequeue(x, ...)

Arguments

x

a queue object

...

arguments passed to other methods

Value

An R object representing the head of the queue

Details

Return the head of the queue while also removing the element from the queue