Add a new element on to the back of the queue

enqueue(x, val, ...)

Arguments

x

a queue object

val

an R object

...

arguments passed to other methods

Value

Nothing useful

Details

Insert an R object into the queue at the tail