Check to see if the input queue is empty

is_empty_input(x, ...)

Arguments

x

a job_queue object

...

arguments passed to other methods

Value

TRUE or FALSE depending on whether the input queue is empty or not