Check to see if the output queue is empty

is_empty_output(x, ...)

Arguments

x

a job_queue object

...

arguments passed to other methods

Value

TRUE or FALSE depending on whether the output queue is empty or not