Move an object from the shelf to the output queue

shelf2output(x, key, val, ...)

Arguments

x

a job_queue object

key

identifier for shelf object

val

an R object to be put in the output queue

...

other arguments passed to methods