R/jobqueue.R
create_job_queue.Rd
Create a job queue and return a job queue object
create_job_queue(qfile, mapsize = 2^30, ...)
the name of the queue
size of the map for LMDB database
other arguments to be passed to mdb_env
mdb_env
an object of class "job_queue" (invisibly) fet
"job_queue"
The queue will be created as a subdirectory named qfile under the current working directory
qfile