R/queue.R
dequeue.Rd
Return the next queue element and remove it from the queue
dequeue(x, ...)
a queue object
arguments passed to other methods
An R object representing the head of the queue
Return the head of the queue while also removing the element from the queue