R/queue.R
enqueue.Rd
Add a new element on to the back of the queue
enqueue(x, val, ...)
a queue object
an R object
arguments passed to other methods
Nothing useful
Insert an R object into the queue at the tail