R/jobqueue.R
is_empty_input.Rd
Check to see if the input queue is empty
is_empty_input(x, ...)
a job_queue object
arguments passed to other methods
TRUE or FALSE depending on whether the input queue is empty or not
TRUE
FALSE