R/jobqueue.R
is_empty_output.Rd
Check to see if the output queue is empty
is_empty_output(x, ...)
a job_queue object
arguments passed to other methods
TRUE or FALSE depending on whether the output queue is empty or not
TRUE
FALSE