R/jobqueue.R
shelf2output.Rd
Move an object from the shelf to the output queue
shelf2output(x, key, val, ...)
a job_queue object
identifier for shelf object
an R object to be put in the output queue
other arguments passed to methods